
Build and Install
===================


********************
Covalent Python API
********************


Covalent Python Api is a package that allows python developers to query all the 
modules from the Covalent API directly with python.

***************
Installation
***************

Installing from pip::

    
    $ pip install covalent-python-api


Or build from source:

- Clone the public repository::

        $ git clone git@bitbucket.org:lluisBrokenC/covalent_python_api.git

- Or download and extract the
  `zipball <https://bitbucket.org/lluisBrokenC/covalent_python_api/get/master.zip>`_

You can now build or install the package:

- Build::

        $ python setup.py build
- Install::

        $ python setup.py install

****************
Documentation
****************

Build Documentation::

    $ python setup.py build_sphinx

View documentation on browser::

        $ file:///path/to/covalent-python-api/build/doc/html/index.html

Also is recommended to check the official Covalent API documentation in:
https://www.covalenthq.com/docs/api/

************************
Copyright and license
************************

Copyright (c) 2021 Lluis Casals Marsol

Licensed under the GNU General Public License v3.0 (GPLv3); you may not use
this work except in compliance with the License. You may obtain a copy of the
License in the LICENSE.txt file, or at:

https://www.gnu.org/licenses/gpl-3.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.

